# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: programme_startrun.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import programme_resource_pb2 as programme__resource__pb2
from ..pb2 import terminaltype_pb2 as terminaltype__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='programme_startrun.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\035com.ubtechinc.alpha.programme',
    serialized_pb=b'\n\x18programme_startrun.proto\x1a\x18programme_resource.proto\x1a\x12terminaltype.proto\"\xce\x01\n\x0fStartRunRequest\x12\x1c\n\tresources\x18\x01 \x03(\x0b\x32\t.Resource\x12#\n\x0cterminalType\x18\x02 \x01(\x0e\x32\r.TerminalType\x12\x18\n\x10programmeVersion\x18\x03 \x01(\x05\x12\x11\n\tclientLan\x18\x04 \x01(\t\x12\x19\n\x11\x63lientVersionName\x18\x05 \x01(\t\x12\x19\n\x11\x63lientVersionCode\x18\x06 \x01(\x05\x12\x15\n\rclientCountry\x18\x07 \x01(\t\"X\n\x10StartRunResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x1d\n\x15robotProgrammeVersion\x18\x03 \x01(\x05\x42\x1f\n\x1d\x63om.ubtechinc.alpha.programmeb\x06proto3'
    ,
    dependencies=[programme__resource__pb2.DESCRIPTOR, terminaltype__pb2.DESCRIPTOR, ])

_STARTRUNREQUEST = _descriptor.Descriptor(
    name='StartRunRequest',
    full_name='StartRunRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='resources', full_name='StartRunRequest.resources', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='terminalType', full_name='StartRunRequest.terminalType', index=1,
            number=2, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='programmeVersion', full_name='StartRunRequest.programmeVersion', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='clientLan', full_name='StartRunRequest.clientLan', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='clientVersionName', full_name='StartRunRequest.clientVersionName', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='clientVersionCode', full_name='StartRunRequest.clientVersionCode', index=5,
            number=6, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='clientCountry', full_name='StartRunRequest.clientCountry', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=75,
    serialized_end=281,
)

_STARTRUNRESPONSE = _descriptor.Descriptor(
    name='StartRunResponse',
    full_name='StartRunResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='StartRunResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='StartRunResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='robotProgrammeVersion', full_name='StartRunResponse.robotProgrammeVersion', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=283,
    serialized_end=371,
)

_STARTRUNREQUEST.fields_by_name['resources'].message_type = programme__resource__pb2._RESOURCE
_STARTRUNREQUEST.fields_by_name['terminalType'].enum_type = terminaltype__pb2._TERMINALTYPE
DESCRIPTOR.message_types_by_name['StartRunRequest'] = _STARTRUNREQUEST
DESCRIPTOR.message_types_by_name['StartRunResponse'] = _STARTRUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StartRunRequest = _reflection.GeneratedProtocolMessageType('StartRunRequest', (_message.Message,), {
    'DESCRIPTOR': _STARTRUNREQUEST,
    '__module__': 'programme_startrun_pb2'
    # @@protoc_insertion_point(class_scope:StartRunRequest)
})
_sym_db.RegisterMessage(StartRunRequest)

StartRunResponse = _reflection.GeneratedProtocolMessageType('StartRunResponse', (_message.Message,), {
    'DESCRIPTOR': _STARTRUNRESPONSE,
    '__module__': 'programme_startrun_pb2'
    # @@protoc_insertion_point(class_scope:StartRunResponse)
})
_sym_db.RegisterMessage(StartRunResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_InstallWheel.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_InstallWheel.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\030com.ubtechinc.alpha.pypi',
  serialized_pb=b'\n\x17PyPi_InstallWheel.proto\"P\n\x13InstallWheelRequest\x12\x11\n\twheelName\x18\x01 \x01(\t\x12\x17\n\x0fserializePacket\x18\x02 \x01(\x0c\x12\r\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\";\n\x14InstallWheelResponse\x12\x12\n\nresultCode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\tB\x1a\n\x18\x63om.ubtechinc.alpha.pypib\x06proto3'
)




_INSTALLWHEELREQUEST = _descriptor.Descriptor(
  name='InstallWheelRequest',
  full_name='InstallWheelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheelName', full_name='InstallWheelRequest.wheelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serializePacket', full_name='InstallWheelRequest.serializePacket', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug', full_name='InstallWheelRequest.debug', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=107,
)


_INSTALLWHEELRESPONSE = _descriptor.Descriptor(
  name='InstallWheelResponse',
  full_name='InstallWheelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='InstallWheelResponse.resultCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='InstallWheelResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=168,
)

DESCRIPTOR.message_types_by_name['InstallWheelRequest'] = _INSTALLWHEELREQUEST
DESCRIPTOR.message_types_by_name['InstallWheelResponse'] = _INSTALLWHEELRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InstallWheelRequest = _reflection.GeneratedProtocolMessageType('InstallWheelRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLWHEELREQUEST,
  '__module__' : 'PyPi_InstallWheel_pb2'
  # @@protoc_insertion_point(class_scope:InstallWheelRequest)
  })
_sym_db.RegisterMessage(InstallWheelRequest)

InstallWheelResponse = _reflection.GeneratedProtocolMessageType('InstallWheelResponse', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLWHEELRESPONSE,
  '__module__' : 'PyPi_InstallWheel_pb2'
  # @@protoc_insertion_point(class_scope:InstallWheelResponse)
  })
_sym_db.RegisterMessage(InstallWheelResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



COMMON = (
    (400, "请求参数错误, 请升级系统"),
    (401, "操作未授权，请稍后再试"),
    (403, "悟空忙碌中，请稍后再试"),
    (404, "系统错误，请升级系统"),
    (408, "悟空忙碌中，请稍后再试"),
    (409, "悟空忙碌中，请稍后再试"),
    (500, "悟空忙碌中，请稍后再试"),
    (501, "系统错误，请升级系统"),
    (504, "系统错误，请升级系统"),
    (1006, "系统错误，请升级系统"),
    (1007, "系统错误，请升级系统"),
    (-61, "该账户已欠费"),
    (-64, "该账户已冻结"),
    (-81, "已开启隐私模式，无法使用该功能"),
    (-92, "已开启隐私模式，无法使用该功能"),
    (-1, "机器人站起失败"),
    (-2, "悟空电量低,请充电后再来点击吧"),
    (-3, "悟空跌倒了，请扶起悟空再试吧"),
    (-4, "悟空正在视频监控中，请稍后再试。"),
    (-5, "悟空正在通话中，请通话结束后再试"),
    (-7, "悟空正在升级中，等我升级完在试吧"),
    (-8, "悟空正在做高难度动作，等他做完再来试试吧"),
    (-9, "悟空还没绑定,请在手机上绑定他吧"),
)

SPEECH = (
    (1, "悟空忙碌中，请稍后再试"),
    (2, "网络错误，请稍后再试"),
    (-1, "TTS内容为空，合成失败"),
    (4404, "播放失败，音频资源已失效"),
    (4400, "音频为空，请选择音效"),
    (4408, "网络错误，请稍后再试"),
    (4500, "网络错误，请稍后再试"),
    (4200, ""),
)

CONTENT = (
    (4404, "悟空忙碌中，请稍后再试"),
    (4400, "网络错误，请稍后再试"),
    (4408, "TTS内容为空，合成失败"),
    (4500, "播放失败，音频资源已失效"),
    (4200, "音频为空，请选择音效"),
)

VISION = (
    (1, "为检测到人脸，请看着悟空的眼睛，不要晃动"),
    (2, "你已经录入过人脸信息"),
    (3, "人脸信息数量已达到上限，请在APP悟空好友中删除人脸后再试"),
    (4, "人脸信息数量已达到上限，请在APP悟空好友中删除人脸后再试"),
    (5, "悟空正在录入人脸信息，请稍后再试"),
    (6, "检测到的人脸过多，请稍后再试"),
    (7, "人脸录入被打断，请稍后再试"),
    (8, "悟空电量低，无法添加新的好友"),
    (9, "网络错误，请稍后再试"),
    (10, "悟空忙碌中，请稍后再试"),
    (11, "悟空正在绘本阅读，请稍后再试"),
    (12, "悟空正处于监控中，请稍后再试"),
    (13, "悟空正在通话中，请稍后再试"),
    (1700, "网络错误，请稍后再试"),
    (2504, "摄像头启动失败，请重试一下"),
    (2505, "摄像头好像被遮挡了，请移开遮挡物再试试"),
    (1600, "识别超时"),
)

MOTION = (
    (1, "悟空忙碌中，请稍后再试"),
    (2, "悟空忙碌中，请稍后再试"),
    (10002, "机器人舵机出现故障"),
    (10003, "机器人舵机自我保护"),
    (10005, "缺少文件，请升级系统"),
    (10006, "数据异常，请升级系统"),
    (10007, "数据异常，请升级系统"),
    (10008, "数据异常，请升级系统"),
    (10009, "数据异常，请升级系统"),
    (10090, "动作正在下载中，请稍后再试"),
    (10004, "执行新动作被中断"),
    (10001, "动作stop中断"),
)

EXPRESS = (
    (10001, "动作stop中断"),
    (10002, "机器人舵机出现故障"),
    (10003, "机器人舵机自我保护"),
    (10004, "执行新动作被中断"),
    (10005, "缺少文件，请升级系统"),
    (10006, "数据异常，请升级系统"),
    (10007, "数据异常，请升级系统"),
    (10008, "数据异常，请升级系统"),
    (10009, "数据异常，请升级系统"),

    (10090, "动作正在下载中，请稍后再试"),

    (1001, "缺少文件，请升级系统"),
    (1002, "缺少文件，请升级系统"),
    (1003, "数据异常，请升级系统"),
    (1004, "数据异常，请升级系统"),
    (1005, "数据异常，请升级系统"),
    (1007, "悟空忙碌中，请稍后再试"),
    (1008, "数据异常，请升级系统"),
)


def get_common_error_str(error_code: int) -> str:
    if error_code == 0:
        return ""

    ret: str = "未知错误"
    for t in COMMON:
        if t[0] == error_code:
            ret = t[1]
            break
    return ret


def get_speech_error_str(error_code: int) -> str:
    ret = None
    for t in SPEECH:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)


def get_content_error_str(error_code: int) -> str:
    ret = None
    for t in CONTENT:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)


def get_vision_error_str(error_code: int) -> str:
    ret = None
    for t in VISION:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)


def get_motion_error_str(error_code: int) -> str:
    ret = None
    for t in MOTION:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)


def get_express_error_str(error_code: int) -> str:
    ret = None
    for t in EXPRESS:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)



from .apis import *
from .channels import *
from .dns import *
from .mini_sdk import *
from .pb2 import *
from .tool import *

name = "mini"

__all__ = [
    'apis',
    'channels',
    'pb2',
    'dns',
    'mini_sdk',
    'get_device_by_name',
    'get_device_list',
    'connect',
    'release',
    'register_msg_handler',
    'unregister_msg_handler',
    'WiFiDevice',
    'WiFiDeviceListener',
    'GetWiFiDeviceListListener',
    'install_py_pkg',
    'uninstall_py_pkg',
    'run_py_pkg',
    'query_py_pkg',
    'list_py_pkg',
    'setup_py_pkg',
    'PCProgramCmdId',
    'PCPyCmdId',
    'COMMON',
    'SPEECH',
    'VISION',
    'MessageHeader',
    'Message',
    'AbstractMsgHandler',
    'CONTENT',
    'MOTION',
    'EXPRESS',
    'get_common_error_str',
    'get_vision_error_str',
    'get_content_error_str',
    'get_express_error_str',
    'get_motion_error_str',
    'get_speech_error_str',
    'parse_body_msg',
    'parse_msg',
    'build_request_msg',
    'build_response_msg',
    'MiniApiResultType',
    'MoveRobotDirection',
    'RobotActionType',
    'RobotAudioRecordControlType',
    'RobotExpressionType',
    'RobotBehaviorControlType',
    'MouthLampColor',
    'MouthLampMode',
    'RobotPosture',
    'HeadRacketType',
    'ObjectRecogniseType',
    'TakePictureType',
    'TTSControlType',
    'AudioStorageType',
    'AudioSearchType',
    'service_type'
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_speechrecognise.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_speechrecognise.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1d\x63odemao_speechrecognise.proto\"+\n\x16SpeechRecogniseRequest\x12\x11\n\ttimeLimit\x18\x01 \x01(\x05\"N\n\x17SpeechRecogniseResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x0c\n\x04text\x18\x03 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_SPEECHRECOGNISEREQUEST = _descriptor.Descriptor(
    name='SpeechRecogniseRequest',
    full_name='SpeechRecogniseRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeLimit', full_name='SpeechRecogniseRequest.timeLimit', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=33,
    serialized_end=76,
)

_SPEECHRECOGNISERESPONSE = _descriptor.Descriptor(
    name='SpeechRecogniseResponse',
    full_name='SpeechRecogniseResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='SpeechRecogniseResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='SpeechRecogniseResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='text', full_name='SpeechRecogniseResponse.text', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=78,
    serialized_end=156,
)

DESCRIPTOR.message_types_by_name['SpeechRecogniseRequest'] = _SPEECHRECOGNISEREQUEST
DESCRIPTOR.message_types_by_name['SpeechRecogniseResponse'] = _SPEECHRECOGNISERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpeechRecogniseRequest = _reflection.GeneratedProtocolMessageType('SpeechRecogniseRequest', (_message.Message,), {
    'DESCRIPTOR': _SPEECHRECOGNISEREQUEST,
    '__module__': 'codemao_speechrecognise_pb2'
    # @@protoc_insertion_point(class_scope:SpeechRecogniseRequest)
})
_sym_db.RegisterMessage(SpeechRecogniseRequest)

SpeechRecogniseResponse = _reflection.GeneratedProtocolMessageType('SpeechRecogniseResponse', (_message.Message,), {
    'DESCRIPTOR': _SPEECHRECOGNISERESPONSE,
    '__module__': 'codemao_speechrecognise_pb2'
    # @@protoc_insertion_point(class_scope:SpeechRecogniseResponse)
})
_sym_db.RegisterMessage(SpeechRecogniseResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getrobotsid.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getrobotsid.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x19\x63odemao_getrobotsid.proto\"\x14\n\x12GetRobotSidRequest\"\'\n\x13GetRobotSidResponse\x12\x10\n\x08robotSid\x18\x01 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_GETROBOTSIDREQUEST = _descriptor.Descriptor(
    name='GetRobotSidRequest',
    full_name='GetRobotSidRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=29,
    serialized_end=49,
)

_GETROBOTSIDRESPONSE = _descriptor.Descriptor(
    name='GetRobotSidResponse',
    full_name='GetRobotSidResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='robotSid', full_name='GetRobotSidResponse.robotSid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=51,
    serialized_end=90,
)

DESCRIPTOR.message_types_by_name['GetRobotSidRequest'] = _GETROBOTSIDREQUEST
DESCRIPTOR.message_types_by_name['GetRobotSidResponse'] = _GETROBOTSIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRobotSidRequest = _reflection.GeneratedProtocolMessageType('GetRobotSidRequest', (_message.Message,), {
    'DESCRIPTOR': _GETROBOTSIDREQUEST,
    '__module__': 'codemao_getrobotsid_pb2'
    # @@protoc_insertion_point(class_scope:GetRobotSidRequest)
})
_sym_db.RegisterMessage(GetRobotSidRequest)

GetRobotSidResponse = _reflection.GeneratedProtocolMessageType('GetRobotSidResponse', (_message.Message,), {
    'DESCRIPTOR': _GETROBOTSIDRESPONSE,
    '__module__': 'codemao_getrobotsid_pb2'
    # @@protoc_insertion_point(class_scope:GetRobotSidResponse)
})
_sym_db.RegisterMessage(GetRobotSidResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio
import logging
from asyncio.futures import Future
from typing import Any, Set, Optional

from google.protobuf import message as _message

from .channels.websocket_client import AbstractMsgHandler
from .channels.websocket_client import ubt_websocket as _websocket
from .dns.dns_browser import WiFiDeviceListener, WiFiDevice
from .dns.dns_browser import browser as _browser

log = logging.getLogger(__name__)
log.addHandler(logging.StreamHandler())
if log.level == logging.NOTSET:
    log.setLevel(logging.INFO)

browser = _browser()
websocket = _websocket()


def set_log_level(level: int, save_file: str = None):
    """
    设置sdk日志级别
    :param level: logging.DEBUG, logging.INFO, logging.WARNING, logging.ERROR
    :param save_file: 需要保存到文件的, 填写日志文件路径

    """
    log.setLevel(level)

    from .dns.dns_browser import log as log1
    log1.setLevel(log.level)

    from .channels.websocket_client import log as log2
    log2.setLevel(log.level)

    if save_file is not None:
        file_handler = logging.FileHandler(save_file)
        log.addHandler(file_handler)
        log1.addHandler(file_handler)
        log2.addHandler(file_handler)


class GetWiFiDeviceListListener(WiFiDeviceListener):
    """
    批量获取机器人设备监听类
    """
    devices: Set[WiFiDevice]

    def __init__(self, devices):
        """
        初始化
        :param devices: Set[WiFiDevice] or None
        """
        self.devices: Set[WiFiDevice] = devices or set()

    def on_device_updated(self, device: WiFiDevice) -> None:
        """
        机器人设备更新了
        :type device: WiFiDevice
        """
        self.devices.update(device)

    def on_device_removed(self, device: WiFiDevice) -> None:
        """
        机器人设备从局域网中移除了
        :param device: WFiDevice
        """
        self.devices.remove(device)

    def on_device_found(self, device: WiFiDevice) -> None:
        """
        扫描到一个机器人设备
        :param device: WFiDevice
        """
        self.devices.add(device)


async def get_user_input(devices: tuple) -> int:
    """
    获取用户输入
    :param devices: 扫描到的机器人设备
    :return: 用户输入值
    """
    try:
        i: int = 0
        for device in devices:
            print('{0}.{1}'.format(i, device))
            i += 1
        num_text = input(f'请输入选择连接的机器人序号:')
    except Exception as e:
        raise e
    else:
        return int(num_text)


def start_scan(loop: asyncio.AbstractEventLoop, name: str) -> Future:
    """
    开启一个扫描机器人设备的Future
    :param loop: 当前事件loop
    :param name: 指定设备名称
    :return: asyncio.Future
    """
    fut = loop.create_future()

    class _InnerLister(WiFiDeviceListener):

        @staticmethod
        def set_result(future: Future, device: WiFiDevice):
            if future.cancelled() or future.done():
                return
            log.info(f"found device : {device}")
            future.set_result(device)

        def on_device_found(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.run_in_executor(None, browser.stop_scan)
                loop.call_soon(_InnerLister.set_result, fut, device)

        def on_device_updated(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.run_in_executor(None, browser.stop_scan)
                loop.call_soon(_InnerLister.set_result, fut, device)

        def on_device_removed(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.call_soon(_InnerLister.set_result, fut, device)

    log.info("start scanning...")
    browser.add_listener(_InnerLister())
    browser.start_scan(0)

    return fut


async def get_device_by_name(name: str, timeout: int) -> Optional[WiFiDevice]:
    """
    获取当前局域网内，指定名字的机器人设备信息
    :param name: 设备序列号
    :param timeout: 扫描超时时间
    :return: Optional[WiFiDevice]
    """

    async def start_scan_async():
        return await start_scan(asyncio.get_running_loop(), name)

    try:
        device: WiFiDevice = await asyncio.wait_for(start_scan_async(), timeout)
        return device
    except asyncio.TimeoutError:
        log.warning(f'scan device timeout')
        return None
    finally:
        browser.stop_scan()
        log.info("stop scan finished.")


async def get_device_list(timeout: int) -> tuple:
    """
    获取当前局域网内所有机器人设备信息
    :param timeout: 超时时间
    :return: ()
    """
    devices: Set[WiFiDevice] = set()
    browser.add_listener(GetWiFiDeviceListListener(devices))
    browser.start_scan(0)
    await asyncio.sleep(timeout)
    browser.remove_all_listener()
    browser.stop_scan()
    return tuple(devices)


async def connect(device: WiFiDevice) -> bool:
    """
    连接机器人设备
    :param device: WiFiDevice
    :return: bool
    """
    return await websocket.connect(device.address)


def register_msg_handler(cmd: int, handler: AbstractMsgHandler):
    """
    注册命令监听器
    :param cmd: 支持的命令请查看: mini.blockapi.cmdid
    :param handler: 命令处理器
    """
    websocket.register_msg_handler(cmd, handler)


def unregister_msg_handler(cmd: int, handler: AbstractMsgHandler):
    """
    反注册命令监听器
    :param cmd: 支持的命令请查看: mini.blockapi.cmdid
    :param handler:
    """
    websocket.unregister_msg_handler(cmd, handler)


async def send_msg(cmd: int, message: _message.Message, timeout: int) -> Any:
    """
    发送一个消息给机器人
    :param cmd:支持的命令请查看: mini.blockapi.cmdid
    :param message:  消息类在: mini.pb2 包内
    :param timeout: 超时时间
    :return:
    """
    return await websocket.send_msg(cmd, message, timeout)


async def release():
    """
    断开链接，释放资源
    """
    await websocket.shutdown()



#!/usr/bin/env python3

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import PCProgramCmdId
from ..pb2.codemao_revertorigin_pb2 import RevertOriginRequest, RevertOriginResponse
from ..pb2.pccodemao_disconnection_pb2 import DisconnectionRequest, DisconnectionResponse
from ..pb2.pccodemao_getappversion_pb2 import GetAppVersionRequest, GetAppVersionResponse
from ..pb2.pccodemao_message_pb2 import Message


class StartRunProgram(BaseApi):
    """进入编程模式api

    机器人进入编程模式

    Args:
        is_serial (bool): 是否等待回复，默认True
    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        """
        执行进入编程模式指令

        Returns:
            GetAppVersionResponse:
        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = GetAppVersionRequest()

        cmd_id = PCProgramCmdId.GET_ROBOT_VERSION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetAppVersionResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetAppVersionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopRunProgram(BaseApi):
    """退出编程模式api

    机器人退出编程模式

    Args:
        is_serial (bool): 是否等待回复，默认True
    """

    def __init__(self, is_serial: bool = True, ):
        self.__isSerial = is_serial

    async def execute(self):
        """
        执行退出编程模式指令

        Returns:
            DisconnectionResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = DisconnectionRequest()

        cmd_id = PCProgramCmdId.DISCONNECTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = DisconnectionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class RevertOrigin(BaseApi):
    """复位api

    机器人复位

    Args:
        is_serial (bool): 是否等待回复，默认True
    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        """
        执行机器人复位指令

        Returns:
            RevertOriginResponse:
        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = RevertOriginRequest()

        cmd_id = PCProgramCmdId.REVERT_ORIGIN_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            RevertOriginResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = RevertOriginResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_controlfindface.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_controlfindface.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1d\x63odemao_controlfindface.proto\"7\n\x16\x43ontrolFindFaceRequest\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"]\n\x17\x43ontrolFindFaceResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\x11\n\tfaceCount\x18\x04 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_CONTROLFINDFACEREQUEST = _descriptor.Descriptor(
    name='ControlFindFaceRequest',
    full_name='ControlFindFaceRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='ControlFindFaceRequest.type', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='timeout', full_name='ControlFindFaceRequest.timeout', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=33,
    serialized_end=88,
)

_CONTROLFINDFACERESPONSE = _descriptor.Descriptor(
    name='ControlFindFaceResponse',
    full_name='ControlFindFaceResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='ControlFindFaceResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='code', full_name='ControlFindFaceResponse.code', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='status', full_name='ControlFindFaceResponse.status', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='faceCount', full_name='ControlFindFaceResponse.faceCount', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=90,
    serialized_end=183,
)

DESCRIPTOR.message_types_by_name['ControlFindFaceRequest'] = _CONTROLFINDFACEREQUEST
DESCRIPTOR.message_types_by_name['ControlFindFaceResponse'] = _CONTROLFINDFACERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlFindFaceRequest = _reflection.GeneratedProtocolMessageType('ControlFindFaceRequest', (_message.Message,), {
    'DESCRIPTOR': _CONTROLFINDFACEREQUEST,
    '__module__': 'codemao_controlfindface_pb2'
    # @@protoc_insertion_point(class_scope:ControlFindFaceRequest)
})
_sym_db.RegisterMessage(ControlFindFaceRequest)

ControlFindFaceResponse = _reflection.GeneratedProtocolMessageType('ControlFindFaceResponse', (_message.Message,), {
    'DESCRIPTOR': _CONTROLFINDFACERESPONSE,
    '__module__': 'codemao_controlfindface_pb2'
    # @@protoc_insertion_point(class_scope:ControlFindFaceResponse)
})
_sym_db.RegisterMessage(ControlFindFaceResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_takepicture.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='pccodemao_takepicture.proto',
  package='packet',
  syntax='proto3',
  serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\022PcTakePictureProto',
  serialized_pb=b'\n\x1bpccodemao_takepicture.proto\x12\x06packet\"2\n\x14PcTakePictureRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\">\n\x15PcTakePictureResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x32\n\x1c\x63om.ubtrobot.pccodemao.protoB\x12PcTakePictureProtob\x06proto3'
)




_PCTAKEPICTUREREQUEST = _descriptor.Descriptor(
  name='PcTakePictureRequest',
  full_name='packet.PcTakePictureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='packet.PcTakePictureRequest.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='packet.PcTakePictureRequest.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=89,
)


_PCTAKEPICTURERESPONSE = _descriptor.Descriptor(
  name='PcTakePictureResponse',
  full_name='packet.PcTakePictureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='packet.PcTakePictureResponse.isSuccess', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='packet.PcTakePictureResponse.resultCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=153,
)

DESCRIPTOR.message_types_by_name['PcTakePictureRequest'] = _PCTAKEPICTUREREQUEST
DESCRIPTOR.message_types_by_name['PcTakePictureResponse'] = _PCTAKEPICTURERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PcTakePictureRequest = _reflection.GeneratedProtocolMessageType('PcTakePictureRequest', (_message.Message,), {
  'DESCRIPTOR' : _PCTAKEPICTUREREQUEST,
  '__module__' : 'pccodemao_takepicture_pb2'
  # @@protoc_insertion_point(class_scope:packet.PcTakePictureRequest)
  })
_sym_db.RegisterMessage(PcTakePictureRequest)

PcTakePictureResponse = _reflection.GeneratedProtocolMessageType('PcTakePictureResponse', (_message.Message,), {
  'DESCRIPTOR' : _PCTAKEPICTURERESPONSE,
  '__module__' : 'pccodemao_takepicture_pb2'
  # @@protoc_insertion_point(class_scope:packet.PcTakePictureResponse)
  })
_sym_db.RegisterMessage(PcTakePictureResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from ..apis import *
from .cmdid import *
from .errors import *
from .base_api import MiniApiResultType
from .api_action import MoveRobotDirection, RobotActionType, RobotAudioRecordControlType
from .api_expression import RobotExpressionType, RobotBehaviorControlType, MouthLampColor, MouthLampMode
from .api_observe import RobotPosture, HeadRacketType
from .api_sence import ObjectRecogniseType, TakePictureType
from .api_sound import TTSControlType, AudioStorageType, AudioSearchType



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_message.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..pb2 import pccodemao_messageheader_pb2 as pccodemao__messageheader__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pccodemao_message.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\034com.ubtrobot.pccodemao.proto',
  serialized_pb=b'\n\x17pccodemao_message.proto\x1a\x1dpccodemao_messageheader.proto\";\n\x07Message\x12\x1e\n\x06header\x18\x01 \x01(\x0b\x32\x0e.MessageHeader\x12\x10\n\x08\x62odyData\x18\x02 \x01(\x0c\x42\x1e\n\x1c\x63om.ubtrobot.pccodemao.protob\x06proto3'
  ,
  dependencies=[pccodemao__messageheader__pb2.DESCRIPTOR,])




_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='Message.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyData', full_name='Message.bodyData', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=117,
)

_MESSAGE.fields_by_name['header'].message_type = pccodemao__messageheader__pb2._MESSAGEHEADER
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'pccodemao_message_pb2'
  # @@protoc_insertion_point(class_scope:Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_wiki.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import cloudwiki_pb2 as cloudwiki__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_wiki.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x12\x63odemao_wiki.proto\x1a\x0f\x63loudwiki.proto\"\"\n\x0bWikiRequest\x12\x13\n\x04wiki\x18\x01 \x01(\x0b\x32\x05.WiKi\"5\n\x0cWikiResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
    ,
    dependencies=[cloudwiki__pb2.DESCRIPTOR, ])

_WIKIREQUEST = _descriptor.Descriptor(
    name='WikiRequest',
    full_name='WikiRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='wiki', full_name='WikiRequest.wiki', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=39,
    serialized_end=73,
)

_WIKIRESPONSE = _descriptor.Descriptor(
    name='WikiResponse',
    full_name='WikiResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='WikiResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='WikiResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=75,
    serialized_end=128,
)

_WIKIREQUEST.fields_by_name['wiki'].message_type = cloudwiki__pb2._WIKI
DESCRIPTOR.message_types_by_name['WikiRequest'] = _WIKIREQUEST
DESCRIPTOR.message_types_by_name['WikiResponse'] = _WIKIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WikiRequest = _reflection.GeneratedProtocolMessageType('WikiRequest', (_message.Message,), {
    'DESCRIPTOR': _WIKIREQUEST,
    '__module__': 'codemao_wiki_pb2'
    # @@protoc_insertion_point(class_scope:WikiRequest)
})
_sym_db.RegisterMessage(WikiRequest)

WikiResponse = _reflection.GeneratedProtocolMessageType('WikiResponse', (_message.Message,), {
    'DESCRIPTOR': _WIKIRESPONSE,
    '__module__': 'codemao_wiki_pb2'
    # @@protoc_insertion_point(class_scope:WikiResponse)
})
_sym_db.RegisterMessage(WikiResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_facedetecttask.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_facedetecttask.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1c\x63odemao_facedetecttask.proto\"j\n\x15\x46\x61\x63\x65\x44\x65tectTaskRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\x12\x0e\n\x06period\x18\x02 \x01(\x05\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\x12\x0e\n\x06switch\x18\x04 \x01(\x08\x12\x11\n\tcommandId\x18\x05 \x01(\t\"a\n\x16\x46\x61\x63\x65\x44\x65tectTaskResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x12\x11\n\tcommandId\x18\x04 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_FACEDETECTTASKREQUEST = _descriptor.Descriptor(
    name='FaceDetectTaskRequest',
    full_name='FaceDetectTaskRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceDetectTaskRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='period', full_name='FaceDetectTaskRequest.period', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='delay', full_name='FaceDetectTaskRequest.delay', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='switch', full_name='FaceDetectTaskRequest.switch', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceDetectTaskRequest.commandId', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=32,
    serialized_end=138,
)

_FACEDETECTTASKRESPONSE = _descriptor.Descriptor(
    name='FaceDetectTaskResponse',
    full_name='FaceDetectTaskResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='count', full_name='FaceDetectTaskResponse.count', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceDetectTaskResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceDetectTaskResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceDetectTaskResponse.commandId', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=140,
    serialized_end=237,
)

DESCRIPTOR.message_types_by_name['FaceDetectTaskRequest'] = _FACEDETECTTASKREQUEST
DESCRIPTOR.message_types_by_name['FaceDetectTaskResponse'] = _FACEDETECTTASKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceDetectTaskRequest = _reflection.GeneratedProtocolMessageType('FaceDetectTaskRequest', (_message.Message,), {
    'DESCRIPTOR': _FACEDETECTTASKREQUEST,
    '__module__': 'codemao_facedetecttask_pb2'
    # @@protoc_insertion_point(class_scope:FaceDetectTaskRequest)
})
_sym_db.RegisterMessage(FaceDetectTaskRequest)

FaceDetectTaskResponse = _reflection.GeneratedProtocolMessageType('FaceDetectTaskResponse', (_message.Message,), {
    'DESCRIPTOR': _FACEDETECTTASKRESPONSE,
    '__module__': 'codemao_facedetecttask_pb2'
    # @@protoc_insertion_point(class_scope:FaceDetectTaskResponse)
})
_sym_db.RegisterMessage(FaceDetectTaskResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

import enum

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import PCProgramCmdId
from ..pb2.codemao_faceanalyze_pb2 import FaceAnalyzeRequest, FaceAnalyzeResponse
from ..pb2.codemao_facedetect_pb2 import FaceDetectRequest, FaceDetectResponse
from ..pb2.codemao_facerecognise_pb2 import FaceRecogniseRequest, FaceRecogniseResponse
from ..pb2.codemao_getinfrareddistance_pb2 import GetInfraredDistanceRequest, GetInfraredDistanceResponse
from ..pb2.codemao_getregisterfaces_pb2 import GetRegisterFacesRequest, GetRegisterFacesResponse
from ..pb2.codemao_recogniseobject_pb2 import RecogniseObjectRequest, RecogniseObjectResponse
from ..pb2.codemao_takepicture_pb2 import TakePictureRequest, TakePictureResponse
from ..pb2.pccodemao_message_pb2 import Message


class FaceDetect(BaseApi):
    """检测人脸个数api

    Args:
        is_serial (bool): 是否等待回复，默认True
        timeout (int): 超时时间，必须大于0

    """

    def __init__(self, is_serial: bool = True, timeout: int = 0):
        assert timeout > 0, 'FaceDetect timeout should be positive'
        self.__isSerial = is_serial
        self.__timeout = timeout

    async def execute(self):
        """
        执行检测人脸个数指令

        Returns:
            FaceDetectResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = FaceDetectRequest()
        request.timeout = self.__timeout

        cmd_id = PCProgramCmdId.FACE_DETECT_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceDetectResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceDetectResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class FaceAnalysis(BaseApi):
    """性别分析api

    通过人脸识别，分析性别

    当多人存在摄像头前时，返回脸面积最大的那个

    Args:
        is_serial (bool): 是否等待回复，默认True
        timeout (int): 超时时间

    返回示例:FaceAnalyzeResponse{"age":24,"gender":99,"height":238,"width":238}

    age:年龄
    gender：[1,100],小于50为女性，大于50为男性
    height：人脸在摄像头画面中的高度
    width：人脸在摄像头画面中的宽度

    """

    def __init__(self, is_serial: bool = True, timeout: int = 0):
        assert timeout > 0, 'FaceAnalysis timeout should be positive'
        self.__isSerial = is_serial
        self.__timeout = timeout

    async def execute(self):
        """
        执行人脸性别分析指令

        Returns:
            FaceAnalyzeResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = FaceAnalyzeRequest()
        request.timeout = self.__timeout

        cmd_id = PCProgramCmdId.FACE_ANALYSIS_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceAnalyzeResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceAnalyzeResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class ObjectRecogniseType(enum.Enum):
    """
    物体识别类型

    水果/手势/花
    """
    FRUIT = 1  # 水果
    GESTURE = 2  # 手势
    FLOWER = 3  # 花


class ObjectRecognise(BaseApi):
    """物体识别api

    机器人通过摄像头识别相应的物体(水果/手势/花)

    Args:
        is_serial (bool): 是否等待回复，默认True
        object_type (ObjectRecogniseType): 物体识别类型，默认FRUIT，水果
        timeout (int): 超时时间
    """

    def __init__(self, is_serial: bool = True, object_type: ObjectRecogniseType = ObjectRecogniseType.FRUIT,
                 timeout: int = 10):
        assert timeout > 0, 'ObjectRecognise timeout should be positive'
        assert object_type is not None and object_type.value > 0, 'objectType should not be None,and should be positive'
        self.__isSerial = is_serial
        self.__objectType = object_type.value
        self.__timeout = timeout

    async def execute(self):
        """
        执行物体识别指令

        Returns:
            RecogniseObjectResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = RecogniseObjectRequest()
        request.objectType = self.__objectType
        request.timeout = self.__timeout

        cmd_id = PCProgramCmdId.RECOGNISE_OBJECT_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            RecogniseObjectResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = RecogniseObjectResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class FaceRecognise(BaseApi):
    """人脸识别api

    机器人通过摄像头识别出所有的人脸信息

    Args:
        is_serial (bool): 是否等待回复，默认True
        timeout (int): 超时时间
    """

    def __init__(self, is_serial: bool = True, timeout: int = 10):
        assert timeout > 0, 'ObjectRecognise timeout should be positive'
        self.__isSerial = is_serial
        self.__timeout = timeout

    async def execute(self):
        """
        执行人脸识别指令

        Returns:
            FaceRecogniseResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = FaceRecogniseRequest()
        request.timeout = self.__timeout

        cmd_id = PCProgramCmdId.FACE_RECOGNISE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceRecogniseResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceRecogniseResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class TakePictureType(enum.Enum):
    """
    拍照类型

    立即拍照/寻找人脸拍照
    """
    IMMEDIATELY = 0  # 立即拍照
    FINDFACE = 1  # 寻找人脸拍照


class TakePicture(BaseApi):
    """拍照api

    控制机器人拍照

    Args:
        is_serial (bool): 是否等待回复，默认True
        take_picture_type (TakePictureType): 拍照类型，默认IMMEDIATELY，立即拍照
    """

    def __init__(self, is_serial: bool = True, take_picture_type: TakePictureType = TakePictureType.IMMEDIATELY):
        self.__isSerial = is_serial
        self.__type = take_picture_type.value

    async def execute(self):
        """
        执行拍照指令

        Returns:
            TakePictureResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = TakePictureRequest()
        request.type = self.__type

        cmd_id = PCProgramCmdId.TAKE_PICTURE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            TakePictureResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = TakePictureResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class GetInfraredDistance(BaseApi):
    """获取红外距离api

    获取距离机器人正面最近的障碍物的红外距离

    Args:
        is_serial (bool): 是否等待回复，默认True

    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        """
        执行获取红外距离的指令

        Returns:
            GetInfraredDistanceResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = GetInfraredDistanceRequest()

        cmd_id = PCProgramCmdId.GET_INFRARED_DISTANCE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetInfraredDistanceResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetInfraredDistanceResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class GetRegisterFaces(BaseApi):
    """获取已注册的人脸列表api

    获取机器人中已注册的人脸列表数据

    Args:
        is_serial (bool): 是否等待回复，默认True

    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        """
        执行获取已注册人脸列表指令

        Returns:
            GetRegisterFacesResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = GetRegisterFacesRequest()

        cmd_id = PCProgramCmdId.GET_REGISTER_FACES_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetRegisterFacesResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetRegisterFacesResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cmprivacymode.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='cmprivacymode.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x13\x63mprivacymode.proto\"6\n\x14\x43mPrivacyModeRequest\x12\x1e\n\x04type\x18\x01 \x01(\x0e\x32\x10.PrivacyModeType\"7\n\x15\x43mPrivacyModeResponse\x12\x1e\n\x04type\x18\x01 \x01(\x0e\x32\x10.PrivacyModeType*:\n\x0fPrivacyModeType\x12\x13\n\x0fPRIVACYMODE_OFF\x10\x00\x12\x12\n\x0ePRIVACYMODE_ON\x10\x01\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
)

_PRIVACYMODETYPE = _descriptor.EnumDescriptor(
    name='PrivacyModeType',
    full_name='PrivacyModeType',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='PRIVACYMODE_OFF', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='PRIVACYMODE_ON', index=1, number=1,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=136,
    serialized_end=194,
)
_sym_db.RegisterEnumDescriptor(_PRIVACYMODETYPE)

PrivacyModeType = enum_type_wrapper.EnumTypeWrapper(_PRIVACYMODETYPE)
PRIVACYMODE_OFF = 0
PRIVACYMODE_ON = 1

_CMPRIVACYMODEREQUEST = _descriptor.Descriptor(
    name='CmPrivacyModeRequest',
    full_name='CmPrivacyModeRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='CmPrivacyModeRequest.type', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=23,
    serialized_end=77,
)

_CMPRIVACYMODERESPONSE = _descriptor.Descriptor(
    name='CmPrivacyModeResponse',
    full_name='CmPrivacyModeResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='CmPrivacyModeResponse.type', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=79,
    serialized_end=134,
)

_CMPRIVACYMODEREQUEST.fields_by_name['type'].enum_type = _PRIVACYMODETYPE
_CMPRIVACYMODERESPONSE.fields_by_name['type'].enum_type = _PRIVACYMODETYPE
DESCRIPTOR.message_types_by_name['CmPrivacyModeRequest'] = _CMPRIVACYMODEREQUEST
DESCRIPTOR.message_types_by_name['CmPrivacyModeResponse'] = _CMPRIVACYMODERESPONSE
DESCRIPTOR.enum_types_by_name['PrivacyModeType'] = _PRIVACYMODETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CmPrivacyModeRequest = _reflection.GeneratedProtocolMessageType('CmPrivacyModeRequest', (_message.Message,), {
    'DESCRIPTOR': _CMPRIVACYMODEREQUEST,
    '__module__': 'cmprivacymode_pb2'
    # @@protoc_insertion_point(class_scope:CmPrivacyModeRequest)
})
_sym_db.RegisterMessage(CmPrivacyModeRequest)

CmPrivacyModeResponse = _reflection.GeneratedProtocolMessageType('CmPrivacyModeResponse', (_message.Message,), {
    'DESCRIPTOR': _CMPRIVACYMODERESPONSE,
    '__module__': 'cmprivacymode_pb2'
    # @@protoc_insertion_point(class_scope:CmPrivacyModeResponse)
})
_sym_db.RegisterMessage(CmPrivacyModeResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_messageheader.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='pccodemao_messageheader.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\022MessageHeaderProto',
  serialized_pb=b'\n\x1dpccodemao_messageheader.proto\"<\n\rMessageHeader\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x42\x32\n\x1c\x63om.ubtrobot.pccodemao.protoB\x12MessageHeaderProtob\x06proto3'
)




_MESSAGEHEADER = _descriptor.Descriptor(
  name='MessageHeader',
  full_name='MessageHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='MessageHeader.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='MessageHeader.target', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='MessageHeader.command', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=93,
)

DESCRIPTOR.message_types_by_name['MessageHeader'] = _MESSAGEHEADER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MessageHeader = _reflection.GeneratedProtocolMessageType('MessageHeader', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEHEADER,
  '__module__' : 'pccodemao_messageheader_pb2'
  # @@protoc_insertion_point(class_scope:MessageHeader)
  })
_sym_db.RegisterMessage(MessageHeader)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

import enum

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import PCProgramCmdId
from ..pb2.codemao_controlbehavior_pb2 import ControlBehaviorRequest, ControlBehaviorResponse
from ..pb2.codemao_controlmouthlamp_pb2 import ControlMouthRequest, ControlMouthResponse
from ..pb2.codemao_playexpression_pb2 import PlayExpressionRequest, PlayExpressionResponse
from ..pb2.codemao_setmouthlamp_pb2 import SetMouthLampRequest, SetMouthLampResponse
from ..pb2.pccodemao_message_pb2 import Message


@enum.unique
class RobotExpressionType(enum.Enum):
    """
    机器人表情类型

    内置/自定义
    """
    INNER = 0  # 内置表情
    CUSTOM = 1  # 自定义表情


class PlayExpression(BaseApi):
    """播放表情api

    Args:
        is_serial (bool): 是否等待回复，默认True
        express_name (str): 表情名称，不可为空或者None
        express_type (RobotExpressionType):表情类型，默认INNER,内置表情

    """

    def __init__(self, is_serial: bool = True, express_name: str = None,
                 express_type: RobotExpressionType = RobotExpressionType.INNER):
        assert express_name is not None and len(express_name), 'PlayExpression expressName should be available'
        self.__isSerial = is_serial
        self.__expressName = express_name
        self.__dirType = express_type.value

    async def execute(self):
        """
        执行播放表情指令

        Returns:
            PlayExpressionResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = PlayExpressionRequest()
        request.expressName = self.__expressName
        request.dirType = self.__dirType

        cmd_id: int = PCProgramCmdId.PLAY_EXPRESSION_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            PlayExpressionResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = PlayExpressionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotBehaviorControlType(enum.Enum):
    """
    表现力控制类型

    开始/停止
    """
    START = 1  # 开始
    STOP = 0  # 停止


class ControlBehavior(BaseApi):
    """控制表现力api

    开始/停止表现力

    Args:
        is_serial (bool): 是否等待回复，默认True
        name (str): 表现力名称，不可为空或None
        control_type (RobotBehaviorControlType): 控制类型，默认START，表示开始执行
    """

    def __init__(self, is_serial: bool = True, name: str = None,
                 control_type: RobotBehaviorControlType = RobotBehaviorControlType.START):
        assert name is not None and len(name), 'ControlBehavior name should be available'
        self.__isSerial = is_serial
        self.__name = name
        self.__eventType = control_type.value

    async def execute(self):
        """
        执行表现力控制指令

        Returns:
            ControlBehaviorResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = ControlBehaviorRequest()
        request.name = self.__name
        request.eventType = self.__eventType

        cmd_id = PCProgramCmdId.CONTROL_BEHAVIOR_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlBehaviorResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlBehaviorResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class MouthLampColor(enum.Enum):
    """
    嘴巴灯颜色

    红色/绿色/蓝色
    """
    RED = 1  # 红色
    GREEN = 2  # 绿色
    BLUE = 3  # 蓝色


@enum.unique
class MouthLampMode(enum.Enum):
    """
    嘴巴灯模式

    普通(常亮)/呼吸
    """
    NORMAL = 0  # 普通模式
    BREATH = 1  # 呼吸模式


class SetMouthLamp(BaseApi):
    """设置嘴巴灯api

    设置嘴巴灯的模式、颜色等参数

    当mode=NORMAL时，duration参数起作用，表示常亮多久时间

    当mode=BREATH，breath_duration参数起作用，表示多久呼吸一次

    Args:
        is_serial (bool): 是否等待回复，默认True
        mode (MouthLampMode): 嘴巴灯模式，默认NORMAL，普通(常亮)模式
        color (MouthLampColor): 嘴巴灯颜色，默认RED，红色
        duration (int): 持续时间，单位为毫秒，-1表示无限时间
        breath_duration (int):闪烁一次时长，单位为毫秒
    """

    def __init__(self, is_serial: bool = True, mode: MouthLampMode = MouthLampMode.NORMAL,
                 color: MouthLampColor = MouthLampColor.RED, duration: int = 0, breath_duration: int = 0):
        self.serial = is_serial
        self.__isSerial = self.serial
        self.__mode = mode.value
        self.__color = color.value
        self.__duration = duration
        self.__breathDuration = breath_duration

    async def execute(self):
        """
        执行设置设置嘴巴灯指令

        Returns:
            SetMouthLampResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = SetMouthLampRequest()
        request.model = self.__mode
        request.color = self.__color
        request.duration = self.__duration
        request.breathDuration = self.__breathDuration

        cmd_id = PCProgramCmdId.SET_MOUTH_LAMP_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            SetMouthLampResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = SetMouthLampResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ControlMouthLamp(BaseApi):
    """控制嘴巴灯开关api

    打开/关闭嘴巴灯
    Args:
        is_serial (bool): 是否等待回复，默认True
        is_open (bool): 是否开启嘴巴灯 默认true，开启嘴巴灯
    """

    def __init__(self, is_serial: bool = True, is_open: bool = True):

        self.__isSerial = is_serial
        self.__isOpen = is_open

    async def execute(self):
        """
        执行控制嘴巴灯指令

        Returns:
            ControlMouthResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = ControlMouthRequest()
        request.isOpen = self.__isOpen

        cmd_id = PCProgramCmdId.SWITCH_MOUTH_LAMP_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlMouthResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlMouthResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_faceanalyze.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_faceinfo_pb2 as codemao__faceinfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_faceanalyze.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x19\x63odemao_faceanalyze.proto\x1a\x16\x63odemao_faceinfo.proto\"%\n\x12\x46\x61\x63\x65\x41nalyzeRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\"b\n\x13\x46\x61\x63\x65\x41nalyzeResponse\x12$\n\tfaceInfos\x18\x01 \x03(\x0b\x32\x11.FaceInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
    ,
    dependencies=[codemao__faceinfo__pb2.DESCRIPTOR, ])

_FACEANALYZEREQUEST = _descriptor.Descriptor(
    name='FaceAnalyzeRequest',
    full_name='FaceAnalyzeRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceAnalyzeRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=53,
    serialized_end=90,
)

_FACEANALYZERESPONSE = _descriptor.Descriptor(
    name='FaceAnalyzeResponse',
    full_name='FaceAnalyzeResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='faceInfos', full_name='FaceAnalyzeResponse.faceInfos', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceAnalyzeResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceAnalyzeResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=92,
    serialized_end=190,
)

_FACEANALYZERESPONSE.fields_by_name['faceInfos'].message_type = codemao__faceinfo__pb2._FACEINFORESPONSE
DESCRIPTOR.message_types_by_name['FaceAnalyzeRequest'] = _FACEANALYZEREQUEST
DESCRIPTOR.message_types_by_name['FaceAnalyzeResponse'] = _FACEANALYZERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceAnalyzeRequest = _reflection.GeneratedProtocolMessageType('FaceAnalyzeRequest', (_message.Message,), {
    'DESCRIPTOR': _FACEANALYZEREQUEST,
    '__module__': 'codemao_faceanalyze_pb2'
    # @@protoc_insertion_point(class_scope:FaceAnalyzeRequest)
})
_sym_db.RegisterMessage(FaceAnalyzeRequest)

FaceAnalyzeResponse = _reflection.GeneratedProtocolMessageType('FaceAnalyzeResponse', (_message.Message,), {
    'DESCRIPTOR': _FACEANALYZERESPONSE,
    '__module__': 'codemao_faceanalyze_pb2'
    # @@protoc_insertion_point(class_scope:FaceAnalyzeResponse)
})
_sym_db.RegisterMessage(FaceAnalyzeResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import PCProgramCmdId
from ..pb2.cloudtranslate_pb2 import Platform, Translate
from ..pb2.cloudwiki_pb2 import WiKi
from ..pb2.codemao_translate_pb2 import TranslateResponse, TranslateRequest
from ..pb2.codemao_wiki_pb2 import WikiRequest, WikiResponse
from ..pb2.pccodemao_message_pb2 import Message


class QueryWiKi(BaseApi):
    """百科api

    默认腾讯百科

    Args:
        is_serial (bool): 是否等待回复，默认True
        query (str): 查询的内容，不能为空或None
    """

    def __init__(self, is_serial: bool = True, query: str = None):
        assert query is not None and len(query), 'QueryWiKi query should be available'
        self.__isSerial = is_serial
        self.__query = query
        self.__platform = Platform.TENCENT

    async def execute(self):
        """
        执行百科指令

        Returns:
            WikiResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        wiki = WiKi()
        wiki.query = self.__query
        wiki.platform = self.__platform

        request = WikiRequest()
        request.wiki.CopyFrom(wiki)

        cmd_id = PCProgramCmdId.WIKI_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            WikiResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = WikiResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StartTranslate(BaseApi):
    """翻译api

    默认百度翻译

    Args:
        is_serial (bool): 是否等待回复，默认True
        query (str): 翻译的内容，不能为空或None
        prefix (str): 前缀
        suffix (str): 后缀
        from_lan (Platform): 翻译的原文语言，不能为None
        to_lan (Platform):  翻译的目标语言，不能为None
        platform (Platform): 翻译平台，默认BAIDU，使用百度翻译

    """

    def __init__(self, is_serial: bool = True, query: str = None, prefix: str = '', suffix: str = '',
                 from_lan: Platform = None, to_lan: Platform = None, platform: Platform = Platform.BAIDU):
        assert query is not None, 'Translate query could not be None'
        assert from_lan is not None, 'Translate from_lan could not be None'
        assert to_lan is not None, 'Translate to_lan could not be None'
        self.__isSerial = is_serial
        self.__query = query
        self.__prefix = prefix
        self.__suffix = suffix
        self.__fromLan = from_lan
        self.__toLan = to_lan
        self.__platform = platform

    async def execute(self):
        """
        执行翻译指令

        Returns:
            TranslateResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        translate = Translate()
        translate.query = self.__query
        translate.prefix = self.__prefix
        translate.suffix = self.__suffix
        translate.platform = self.__platform
        # translate.from = self.__fromLan
        setattr(translate, "from", self.__fromLan)
        translate.to = self.__toLan

        request = TranslateRequest()
        request.translate.CopyFrom(translate)

        cmd_id = PCProgramCmdId.TRANSLATE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            TranslateResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = TranslateResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getinfrareddistance.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getinfrareddistance.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n!codemao_getinfrareddistance.proto\"\x1c\n\x1aGetInfraredDistanceRequest\"/\n\x1bGetInfraredDistanceResponse\x12\x10\n\x08\x64istance\x18\x01 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_GETINFRAREDDISTANCEREQUEST = _descriptor.Descriptor(
    name='GetInfraredDistanceRequest',
    full_name='GetInfraredDistanceRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=37,
    serialized_end=65,
)

_GETINFRAREDDISTANCERESPONSE = _descriptor.Descriptor(
    name='GetInfraredDistanceResponse',
    full_name='GetInfraredDistanceResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='distance', full_name='GetInfraredDistanceResponse.distance', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=67,
    serialized_end=114,
)

DESCRIPTOR.message_types_by_name['GetInfraredDistanceRequest'] = _GETINFRAREDDISTANCEREQUEST
DESCRIPTOR.message_types_by_name['GetInfraredDistanceResponse'] = _GETINFRAREDDISTANCERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetInfraredDistanceRequest = _reflection.GeneratedProtocolMessageType('GetInfraredDistanceRequest', (_message.Message,),
                                                                      {
                                                                          'DESCRIPTOR': _GETINFRAREDDISTANCEREQUEST,
                                                                          '__module__': 'codemao_getinfrareddistance_pb2'
                                                                          # @@protoc_insertion_point(class_scope:GetInfraredDistanceRequest)
                                                                      })
_sym_db.RegisterMessage(GetInfraredDistanceRequest)

GetInfraredDistanceResponse = _reflection.GeneratedProtocolMessageType('GetInfraredDistanceResponse',
                                                                       (_message.Message,), {
                                                                           'DESCRIPTOR': _GETINFRAREDDISTANCERESPONSE,
                                                                           '__module__': 'codemao_getinfrareddistance_pb2'
                                                                           # @@protoc_insertion_point(class_scope:GetInfraredDistanceResponse)
                                                                       })
_sym_db.RegisterMessage(GetInfraredDistanceResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getactionlist.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_actioninfo_pb2 as codemao__actioninfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getactionlist.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1b\x63odemao_getactionlist.proto\x1a\x18\x63odemao_actioninfo.proto\"@\n\x14GetActionListRequest\x12\x14\n\x0clanguageType\x18\x01 \x01(\t\x12\x12\n\nactionType\x18\x02 \x01(\x05\"g\n\x15GetActionListResponse\x12\'\n\nactionList\x18\x01 \x03(\x0b\x32\x13.ActionInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
    ,
    dependencies=[codemao__actioninfo__pb2.DESCRIPTOR, ])

_GETACTIONLISTREQUEST = _descriptor.Descriptor(
    name='GetActionListRequest',
    full_name='GetActionListRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='languageType', full_name='GetActionListRequest.languageType', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='actionType', full_name='GetActionListRequest.actionType', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=57,
    serialized_end=121,
)

_GETACTIONLISTRESPONSE = _descriptor.Descriptor(
    name='GetActionListResponse',
    full_name='GetActionListResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='actionList', full_name='GetActionListResponse.actionList', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='GetActionListResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='GetActionListResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=123,
    serialized_end=226,
)

_GETACTIONLISTRESPONSE.fields_by_name['actionList'].message_type = codemao__actioninfo__pb2._ACTIONINFORESPONSE
DESCRIPTOR.message_types_by_name['GetActionListRequest'] = _GETACTIONLISTREQUEST
DESCRIPTOR.message_types_by_name['GetActionListResponse'] = _GETACTIONLISTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetActionListRequest = _reflection.GeneratedProtocolMessageType('GetActionListRequest', (_message.Message,), {
    'DESCRIPTOR': _GETACTIONLISTREQUEST,
    '__module__': 'codemao_getactionlist_pb2'
    # @@protoc_insertion_point(class_scope:GetActionListRequest)
})
_sym_db.RegisterMessage(GetActionListRequest)

GetActionListResponse = _reflection.GeneratedProtocolMessageType('GetActionListResponse', (_message.Message,), {
    'DESCRIPTOR': _GETACTIONLISTRESPONSE,
    '__module__': 'codemao_getactionlist_pb2'
    # @@protoc_insertion_point(class_scope:GetActionListResponse)
})
_sym_db.RegisterMessage(GetActionListResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

import enum

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import PCProgramCmdId
from ..pb2.codemao_changerobotvolume_pb2 import ChangeRobotVolumeRequest, ChangeRobotVolumeResponse
from ..pb2.codemao_controlrobotrecord_pb2 import ControlRobotRecordRequest, ControlRobotRecordResponse
from ..pb2.codemao_getactionlist_pb2 import GetActionListRequest, GetActionListResponse
from ..pb2.codemao_moverobot_pb2 import MoveRobotRequest, MoveRobotResponse
from ..pb2.codemao_playaction_pb2 import PlayActionRequest, PlayActionResponse
from ..pb2.codemao_playcustomaction_pb2 import PlayCustomActionRequest, PlayCustomActionResponse
from ..pb2.codemao_stopaction_pb2 import StopActionRequest, StopActionResponse
from ..pb2.codemao_stopcustomaction_pb2 import StopCustomActionRequest, StopCustomActionResponse
from ..pb2.pccodemao_message_pb2 import Message


class PlayAction(BaseApi):
    """执行动作api

    机器人执行一个指定名称的本地(内置/自定义)动作
    动作名称可用GetActionList获取

    Args:
        is_serial (bool): 是否等待回复，默认True
        action_name (str): 动作名称，不能为none或空字符串

    #PlayActionResponse.isSuccess : 是否成功

    #PlayActionResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, action_name: str = None):
        """执行动作api初始化
        """
        assert action_name is not None and len(action_name), 'PlayAction actionName should be available'
        self.__isSerial = is_serial
        self.__actionName = action_name

    async def execute(self):
        """发送执行动作指令

        Returns:
            PlayActionResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = PlayActionRequest()
        request.actionName = self.__actionName

        cmd_id = PCProgramCmdId.PLAY_ACTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """解析回复指令

        Args:
            message (Message):待解析的Message对象

        Returns:
            PlayActionResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = PlayActionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopAllAction(BaseApi):
    """停止所有动作api

    停止所有正在执行的动作

    Args
        is_serial (bool): 是否等待回复，默认True

    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        """
        发送停止所有动作指令

        Returns:
            StopActionResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = StopActionRequest()

        cmd_id = PCProgramCmdId.STOP_ACTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            StopActionResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = StopActionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class MoveRobotDirection(enum.Enum):
    """机器人移动方向
    """
    FORWARD = 3  # 向前
    BACKWARD = 4  # 向后
    LEFTWARD = 1  # 向左
    RIGHTWARD = 2  # 向右


class MoveRobot(BaseApi):
    """控制机器人移动api

    控制机器人往某个方向(MoveRobotDirection)移动n步

    Args:
        is_serial (bool): 是否等待回复，默认True
        direction (MoveRobotDirection): 机器人移动方向，默认FORWARD，向前移动
        step (int): 步数，默认1步

    #MoveRobotResponse.isSuccess : 是否成功　

    #MoveRobotResponse.code : 返回码

    """

    def __init__(self, is_serial: bool = True, direction: MoveRobotDirection = MoveRobotDirection.FORWARD,
                 step: int = 1):
        assert direction is not None and isinstance(direction,
                                                    MoveRobotDirection) > 0, 'direction should not be None,and should be Positive'
        assert step is not None and step > 0, 'step should not be None,and should be Positive'
        self.__isSerial = is_serial
        self.__direction = direction.value
        self.__step = step

    async def execute(self):
        """发送机器人移动指令

        Returns:
            MoveRobotResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = MoveRobotRequest()
        request.direction = self.__direction
        request.step = self.__step

        cmd_id = PCProgramCmdId.MOVE_ROBOT_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            MoveRobotResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = MoveRobotResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotActionType(enum.Enum):
    """
    机器人动作类型

    内置：机器人内置的不可修改的动作文件

    自定义: 放置在sdcard/customize/action目录下可被开发者修改的动作文件

    """
    INNER = 0  # 内置
    CUSTOM = 1  # 自定义


class GetActionList(BaseApi):
    """获取机器人动作列表api

    获取存储在机器人本地(内置/自定义)的动作文件列表

    Args:
        is_serial (bool): 是否等待回复，默认True
        action_type (RobotActionType): 动作类型，默认为INNER，内置动作

    #GetActionListResponse.actionList : 动作列表

    #GetActionListResponse.isSuccess : 是否成功

    #GetActionListResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, action_type: RobotActionType = RobotActionType.INNER):
        assert action_type is not None and isinstance(action_type,
                                                      RobotActionType), 'action_type should not be available'
        self.__isSerial = is_serial
        self.__actionType = action_type.value

    async def execute(self):
        """发送获取机器人动作列表指令

        Returns:
            GetActionListResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = GetActionListRequest()
        request.actionType = self.__actionType

        cmd_id = PCProgramCmdId.GET_ACTION_LIST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetActionListResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetActionListResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class PlayCustomAction(BaseApi):
    """执行自定义动作api

    执行一个指定名称的自定义机器人动作
    动作名称可用GetActionList获取

    Args:
        is_serial (bool): 是否等待回复，默认True
        action_name (str): 自定义动作名称，不可为空或者None
    """

    def __init__(self, is_serial: bool = True, action_name: str = None):

        assert action_name is not None and len(action_name) > 0, 'PlayCustomAction actionName should be available'
        self.__isSerial = is_serial
        self.__actionName = action_name

    async def execute(self):
        """发送执行自定义动作指令

        Returns:
            PlayCustomActionResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = PlayCustomActionRequest()
        request.actionName = self.__actionName

        cmd_id = PCProgramCmdId.PLAY_CUSTOM_ACTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            PlayCustomActionResponse:

        """

        if isinstance(message, Message):
            data = message.bodyData
            response = PlayCustomActionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopCustomAction(BaseApi):
    """停止自定义动作api

    停止指定的自定义动作

    Args:
        is_serial (bool): 是否等待回复，默认True
        action_name (str): 自定义动作名称，不可为空或None

    """

    def __init__(self, is_serial: bool = True, action_name: str = None):
        assert action_name is not None and len(action_name) > 0, 'StopCustomAction actionName should be available'
        self.__isSerial = is_serial
        self.__actionName = action_name

    async def execute(self):
        """执行停止自定义动作指令

        Returns:
            StopCustomActionResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = StopCustomActionRequest()
        request.actionName = self.__actionName

        cmd_id = PCProgramCmdId.STOP_CUSTOM_ACTION_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            StopCustomActionResponse:

        """

        if isinstance(message, Message):
            data = message.bodyData
            response = StopCustomActionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ChangeRobotVolume(BaseApi):
    """设置机器人音量api

    调整机器人音量

    Args:
        is_serial (bool): 是否等待回复，默认True
        volume (float): 音量，范围[0.0,1.0]，默认0.0

    #ChangeRobotVolumeResponse.isSuccess : 是否成功

    #ChangeRobotVolumeResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, volume: float = 0.0):
        assert 0.0 <= volume <= 1.0, 'ChangeRobotVolume volume should be in range[0.0,1.0]'
        self.__isSerial = is_serial
        self.__volume = volume

    async def execute(self):
        """发送设置机器人音量指令

        Returns:
            ChangeRobotVolumeResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = ChangeRobotVolumeRequest()
        request.volume = self.__volume

        cmd_id = PCProgramCmdId.CHANGE_ROBOT_VOLUME_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ChangeRobotVolumeResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ChangeRobotVolumeResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotAudioRecordControlType(enum.Enum):
    """
    机器人录音控制类型
    """
    START_RECORD = 0  # 开始录音
    STOP_RECORD = 1  # 停止录音
    START_PLAY = 2  # 开始播放
    STOP_PLAY = 3  # 停止播放
    PAUSE_PLAY = 4  # 暂停播放
    CONTINUE_PLAY = 5  # 继续播放
    RENAME_FILE = 6  # 重命名文件


class ControlRobotAudioRecord(BaseApi):
    """控制机器人录音/播放api

    Args:
        is_serial (bool): 是否等待回复，默认True
        control_type (RobotAudioRecordControlType): 控制类型，默认START_RECORD，开始录音
        time_limit (int): 录音时长，单位ms，默认0
        file_name (str): 录音文件存储名称
        new_file_name (str): 重命名录音文件的名称

    """

    def __init__(self, is_serial: bool = True,
                 control_type: RobotAudioRecordControlType = RobotAudioRecordControlType.START_RECORD,
                 time_limit: int = 0, file_name: str = None,
                 new_file_name: str = None):
        # assert ptype >= 0, 'RobotAudioRecord type should be positive'
        self.__isSerial = is_serial
        self.__control_type = control_type.value
        self.__timeLimit = time_limit
        self.__id = file_name
        self.__newId = new_file_name

    async def execute(self):
        """发送控制录音指令

        Returns:
            ControlRobotRecordResponse:

        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT
        request = ControlRobotRecordRequest()
        request.type = self.__control_type
        request.timeLimit = self.__timeLimit
        request.id = self.__id
        request.newId = self.__newId

        cmd_id = PCProgramCmdId.CONTROL_ROBOT_AUDIO_RECORD.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlRobotRecordResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlRobotRecordResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



#!/usr/bin/env python
# coding=utf-8

import setuptools

with open("README.md", "r") as f:
    long_desc = f.read()

with open("LICENSE", "r") as f:
    license_txt = f.read()

setuptools.setup(
    name="alphamini",
    version="0.1.1",
    author='logic.peng',
    author_email='logic.peng@ubtrobot.com',
    description="python sdk for ubtech alpha mini robot",
    long_description=long_desc,
    long_description_content_type="text/markdown",
    license="GPLv3",
    python_requires='>=3.6',
    # url="",
    packages=setuptools.find_packages(exclude=["*.test", "*.test.*", "test.*", "test*", "test"]),  # 排除掉测试包
    # packages=['mini'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'setup_py_pkg = mini.tool.pkg_tool:setup_py_pkg',
            'install_py_pkg = mini.tool.pkg_tool:install_py_pkg',
            'uninstall_py_pkg = mini.tool.pkg_tool:uninstall_py_pkg',
            'run_py_pkg = mini.tool.pkg_tool:run_py_pkg',

            'query_py_pkg = mini.tool.pkg_tool:show_py_pkg',
            'list_py_pkg = mini.tool.pkg_tool:list_py_pkg2',
        ],
    },
    install_requires=[
        'websockets',
        'ifaddr',
        'protobuf'
    ],
    zip_safe=False
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_GetWheelList.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_GetWheelList.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\030com.ubtechinc.alpha.pypi',
  serialized_pb=b'\n\x17PyPi_GetWheelList.proto\"\x15\n\x13GetWheelListRequest\"I\n\x14GetWheelListResponse\x12\x12\n\nresultCode\x18\x01 \x01(\x05\x12\x0e\n\x06Wheels\x18\x02 \x03(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\tB\x1a\n\x18\x63om.ubtechinc.alpha.pypib\x06proto3'
)




_GETWHEELLISTREQUEST = _descriptor.Descriptor(
  name='GetWheelListRequest',
  full_name='GetWheelListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=48,
)


_GETWHEELLISTRESPONSE = _descriptor.Descriptor(
  name='GetWheelListResponse',
  full_name='GetWheelListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='GetWheelListResponse.resultCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Wheels', full_name='GetWheelListResponse.Wheels', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='GetWheelListResponse.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=123,
)

DESCRIPTOR.message_types_by_name['GetWheelListRequest'] = _GETWHEELLISTREQUEST
DESCRIPTOR.message_types_by_name['GetWheelListResponse'] = _GETWHEELLISTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetWheelListRequest = _reflection.GeneratedProtocolMessageType('GetWheelListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWHEELLISTREQUEST,
  '__module__' : 'PyPi_GetWheelList_pb2'
  # @@protoc_insertion_point(class_scope:GetWheelListRequest)
  })
_sym_db.RegisterMessage(GetWheelListRequest)

GetWheelListResponse = _reflection.GeneratedProtocolMessageType('GetWheelListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWHEELLISTRESPONSE,
  '__module__' : 'PyPi_GetWheelList_pb2'
  # @@protoc_insertion_point(class_scope:GetWheelListResponse)
  })
_sym_db.RegisterMessage(GetWheelListResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

# 每种传感器做一个单例对象进行监听

import enum
import asyncio

from ..apis.base_api import BaseEventApi, BaseApiNoNeedResponse
from ..apis.cmdid import PCProgramCmdId
from ..pb2.codemao_facedetecttask_pb2 import FaceDetectTaskRequest, FaceDetectTaskResponse
from ..pb2.codemao_facerecognisetask_pb2 import FaceRecogniseTaskRequest, FaceRecogniseTaskResponse
from ..pb2.codemao_observefallclimb_pb2 import ObserveFallClimbRequest, ObserveFallClimbResponse
from ..pb2.codemao_observeheadracket_pb2 import ObserveHeadRacketRequest, ObserveHeadRacketResponse
from ..pb2.codemao_observeinfrareddistance_pb2 import ObserveInfraredDistanceRequest, ObserveInfraredDistanceResponse
from ..pb2.codemao_speechrecognise_pb2 import SpeechRecogniseRequest, SpeechRecogniseResponse
from ..pb2.codemao_stopspeechrecognise_pb2 import StopSpeechRecogniseRequest, StopSpeechRecogniseResponse
from ..pb2.pccodemao_message_pb2 import Message


class ObserveSpeechRecognise(BaseEventApi):
    """监听语音识别api

    监听语音识别事件，机器人上报语音识别后的文字

    #SpeechRecogniseResponse.text : 识别后的文字

    #SpeechRecogniseResponse.isSuccess : 是否成功

    #SpeechRecogniseResponse.resultCode : 返回码

    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.SPEECH_RECOGNISE.value

        message = SpeechRecogniseRequest()

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=message)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            SpeechRecogniseResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = SpeechRecogniseResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):
        """
        停止语音识别，停止监听语音识别

        Returns:
            None:

        """

        asyncio.create_task(StopSpeechRecognise().execute())

        super().stop()


class StopSpeechRecognise(BaseApiNoNeedResponse):
    """停止语音识别api

    """

    async def execute(self):
        """
        执行停止语音识别指令

        Returns:
            bool: 是否发送指令成功

        """

        request = StopSpeechRecogniseRequest()

        cmd_id = PCProgramCmdId.STOP_SPEECH_RECOGNISE_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            StopSpeechRecogniseResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = StopSpeechRecogniseResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ObserveFaceDetect(BaseEventApi):
    """监听人脸个数api

    监听人脸个数事件，机器人上报检测到的人脸个数

    单次检测超时时间1s，侦测间隔1s

    # FaceDetectTaskResponse.count：人脸个数

    # FaceDetectTaskResponse.isSuccess：是否成功

    # FaceDetectTaskResponse.resultCode：返回码
    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.FACE_DETECT_TASK_REQUEST.value

        request = FaceDetectTaskRequest()

        # 单次侦测超时时间
        request.timeout = 1000

        # 侦测间隔时间
        request.period = 1000

        # 任务延时时间
        request.delay = 0

        # 检测开关
        request.switch = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceDetectTaskResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceDetectTaskResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):
        """
        停止人脸个数检测，停止监听人脸个数

        Returns:
            None:

        """

        asyncio.create_task(StopFaceDetect().execute())

        super().stop()


class StopFaceDetect(BaseApiNoNeedResponse):
    """停止人脸个数检测api

    """

    async def execute(self):
        """
        执行停止人脸个数检测指令

        Returns:
            None:
        """

        request = FaceDetectTaskRequest()

        # 检测开关
        request.switch = False

        cmd_id = PCProgramCmdId.FACE_DETECT_TASK_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceDetectTaskResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceDetectTaskResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ObserveFaceRecognise(BaseEventApi):
    """监听人脸识别api

    监听人脸识别事件，机器人上报识别到的人脸信息(数组)

    如果是已注册的人脸，返回人脸详细信息：id，名字，性别，年龄

    如果是陌生人，返回 name: "stranger"

    单次检测超时时间1s，侦测间隔1s

    # FaceRecogniseTaskResponse.faceInfos: [FaceInfoResponse] 人脸信息数组

    # FaceInfoResponse.id, FaceInfoResponse.name,FaceInfoResponse.gender,FaceInfoResponse.age：人脸详细信息

    # FaceRecogniseTaskResponse.isSuccess：是否成功

    # FaceRecogniseTaskResponse.resultCode：返回码

    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.FACE_RECOGNISE_TASK_REQUEST.value

        request = FaceRecogniseTaskRequest()

        # 单次侦测超时时间
        request.timeout = 1000

        # 侦测间隔时间
        request.period = 1000

        # 任务延时时间
        request.delay = 0

        # 检测开关
        request.switch = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceRecogniseTaskResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceRecogniseTaskResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):
        """
        停止人脸识别，停止监听人脸识别

        Returns:
            None:

        """

        asyncio.create_task(StopFaceRecognise().execute())

        super().stop()


class StopFaceRecognise(BaseApiNoNeedResponse):
    """停止人脸识别api

    """

    async def execute(self):
        """
        执行停止人脸识别指令

        Returns:
            FaceRecogniseTaskResponse:

        """

        request = FaceRecogniseTaskRequest()

        # 检测开关
        request.switch = False

        cmd_id = PCProgramCmdId.FACE_RECOGNISE_TASK_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceRecogniseTaskResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceRecogniseTaskResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ObserveInfraredDistance(BaseEventApi):
    """监听红外距离api

    监听红外距离事件，机器人上报检测到的与面前最近障碍物的红外距离

    检测周期1s

    # ObserveInfraredDistanceResponse.distance：红外距离

    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.SUBSCRIBE_INFRARED_DISTANCE_REQUEST.value

        request = ObserveInfraredDistanceRequest()

        # 检测周期
        request.samplingPeriod = 1000

        # 检测开关
        request.isSubscribe = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ObserveInfraredDistanceResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveInfraredDistanceResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):
        """
        停止红外距离检测，停止监听红外距离

        Returns:
            None:
        """

        asyncio.create_task(StopObserveInfraredDistance().execute())

        super().stop()


class StopObserveInfraredDistance(BaseApiNoNeedResponse):
    """停止红外距离监测api

    """

    async def execute(self):
        """
        执行停止红外监测指令

        Returns:
            ObserveInfraredDistanceResponse:

        """

        request = ObserveInfraredDistanceRequest()

        # 检测开关
        request.isSubscribe = False

        cmd_id = PCProgramCmdId.FACE_RECOGNISE_TASK_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ObserveInfraredDistanceResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveInfraredDistanceResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotPosture(enum.Enum):
    """
    机器人姿势

    站立/左劈叉/右劈叉/坐下/蹲下/跪下/侧躺/平躺/左劈叉1/右劈叉2/弯腰
    """
    STAND = 1  # 站立
    SPLITS_LEFT = 2  # 左劈叉
    SPLITS_RIGHT = 3  # 右劈叉
    SIT_DOWN = 4  # 坐下
    SQUAT_DOWN = 5  # 蹲下
    KNEELING = 6  # 跪下
    LYING = 7  # 侧躺
    LYING_DOWN = 8  # 平躺
    SPLITS_LEFT_1 = 9  # 左劈叉1
    SPLITS_RIGHT_2 = 10  # 右劈叉2
    BEND = 11  # 弯腰


class ObserveRobotPosture(BaseEventApi):
    """监听机器人姿态api

    监听机器人姿态变化事件，机器上报当前的姿态RobotPosture(当发生姿态发生改变的时候)

    #ObserveFallClimbResponse.status : 机器姿态，数值对应RobotPosture

    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.SUBSCRIBE_ROBOT_POSTURE_REQUEST.value

        request = ObserveFallClimbRequest()

        # 检测开关
        request.isSubscribe = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ObserveFallClimbResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveFallClimbResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):
        """
        停止机器人姿势检测，停止监听机器人姿势

        Returns:
            None:

        """

        asyncio.create_task(StopObserveRobotPosture().execute())

        super().stop()


class StopObserveRobotPosture(BaseApiNoNeedResponse):
    """停止监听机器人姿态api

    """

    async def execute(self):
        """
        执行停止机器人姿态监测

        Returns:
            ObserveFallClimbResponse:

        """

        request = ObserveFallClimbRequest()

        # 检测开关
        request.isSubscribe = False

        cmd_id = PCProgramCmdId.SUBSCRIBE_ROBOT_POSTURE_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ObserveFallClimbResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveFallClimbResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class HeadRacketType(enum.Enum):
    """
    拍头方式

    单击/长按/双击

    """
    SINGLE_CLICK = 1  # 单击
    LONG_PRESS = 2  # 长按
    DOUBLE_CLICK = 3  # 双击


class ObserveHeadRacket(BaseEventApi):
    """监听拍头事件api

    监听拍头事件，当机器人头部被拍击时，上报拍头类型

    # ObserveHeadRacketResponse.type : 拍头类型，HeadRacketType

    """

    async def execute(self):
        pass

    def __init__(self):

        cmd_id = PCProgramCmdId.SUBSCRIBE_HEAD_RACKET_REQUEST.value

        message = ObserveHeadRacketRequest()

        # 检测开关
        message.isSubscribe = True

        BaseEventApi.__init__(self, cmd_id=cmd_id, message=message)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ObserveHeadRacketResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveHeadRacketResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

    def stop(self):
        """
        停止机器人拍头事件检测，停止监听机器人拍头事件

        Returns:
            None:

        """

        asyncio.create_task(StopObserveHeadRacket().execute())

        super().stop()


class StopObserveHeadRacket(BaseApiNoNeedResponse):
    """停止拍头事件监测api

    """

    async def execute(self):
        """
        执行停止拍头事件监测指令

        Returns:
            ObserveHeadRacketResponse

        """

        request = ObserveHeadRacketRequest()

        # 检测开关
        request.isSubscribe = False

        cmd_id = PCProgramCmdId.SUBSCRIBE_ROBOT_POSTURE_REQUEST.value

        return await self.send(cmd_id, request)

    def parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ObserveHeadRacketResponse:

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ObserveHeadRacketResponse()
            response.ParseFromString(data)
            return response
        else:
            return None
